@@ -63,9 +63,7 @@ def init(name: str):
         click.echo(f'Project with name "{name}" already exists. Exiting.')
         exit(0)
 
-    app_is_package = open(os.path.join(
-        os.getcwd(), name, name, '__init__.py'), 'w')
-    app_is_package.close()
+    
     os.makedirs(os.path.join(os.getcwd(), name, name, 'ext'))
     ext_is_package = open(os.path.join(
         os.getcwd(), name, name, 'ext', '__init__.py'), 'w')
@@ -74,6 +72,9 @@ def init(name: str):
     blueprint_is_package = open(os.path.join(
         os.getcwd(), name, name, 'ext', '__init__.py'), 'w')
     blueprint_is_package.close()
+    app_is_package = open(os.path.join(
+        os.getcwd(), name, name, '__init__.py'), 'w')
+    app_is_package.close()
 
     os.makedirs(os.path.join(os.getcwd(), name, name, 'templates'))
     os.makedirs(os.path.join(os.getcwd(), name, name, 'static'))
@@ -113,7 +114,7 @@ def init(name: str):
     add_support_to(name, 'Flask==2.0.2')
     add_support_to(name, 'dynaconf==3.1.7')
     add_support_to(name, 'toml')
-    add_support_to(name, 'flaskstarter==0.4')
+    add_support_to(name, f'flaskstarter=={__version__}')
 
     click.echo('If you do have other requirements, feel free to customize it.')
 
